pub struct MarkdownDocument { /* private fields */ }Expand description
A parsed Markdown document.
Implementations
Sourceimpl MarkdownDocument
impl MarkdownDocument
Sourcepub fn new(source: impl Into<String>) -> Self
pub fn new(source: impl Into<String>) -> Self
Creates a document by parsing Markdown with the supported GFM extensions enabled.
Sourcepub fn parse(source: impl Into<String>) -> Self
pub fn parse(source: impl Into<String>) -> Self
Parses Markdown with the supported GFM extensions enabled.
Sourcepub fn from_source(source: impl Into<String>) -> Self
pub fn from_source(source: impl Into<String>) -> Self
Alias for Self::parse that makes the source-oriented API explicit.
Sourcepub fn parse_with_metadata(
source_path: Option<String>,
title: Option<String>,
source: impl Into<String>,
) -> Self
pub fn parse_with_metadata( source_path: Option<String>, title: Option<String>, source: impl Into<String>, ) -> Self
Parses Markdown while retaining optional host-provided metadata.
pub fn source_styles(&self) -> &[MarkdownSourceStyle]
Sourcepub fn source_path(&self) -> Option<&str>
pub fn source_path(&self) -> Option<&str>
Returns the optional source path supplied by the host.
Sourcepub fn blocks(&self) -> &[MarkdownBlock]
pub fn blocks(&self) -> &[MarkdownBlock]
Returns the top-level semantic blocks.
Sourcepub fn outline(&self) -> &[MarkdownHeading]
pub fn outline(&self) -> &[MarkdownHeading]
Returns headings in document order.
Sourcepub fn targets(&self) -> &[MarkdownTarget]
pub fn targets(&self) -> &[MarkdownTarget]
Returns all commentable targets in document order.
Sourcepub fn target(&self, id: MarkdownTargetId) -> Option<&MarkdownTarget>
pub fn target(&self, id: MarkdownTargetId) -> Option<&MarkdownTarget>
Finds a target by its document-local ID.
pub fn code_blocks(&self) -> Vec<&MarkdownCodeBlock>